<?php

//$content_width is required even though this is a variable-width theme
if ( ! isset( $dw_cryosis_content_width ) ) {
	$dw_cryosis_content_width = 400;
}

//makes replying look neat
if ( ! function_exists( 'dw_cryosis_threaded_comments' ) ) :
	function dw_cryosis_threaded_comments() {
		if ( get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'dw_cryosis_threaded_comments' );
endif;

// displays "Comments are closed" instead of comment form when comments are closed.
if ( ! function_exists( 'dw_cryosis_closed_comments' ) ) :
	function dw_cryosis_closed_comments() {
		echo '<p>', esc_html__( 'Comments are closed.', 'dw-cryosis' ), '</p>';
	}
	add_action( 'comment_form_comments_closed', 'dw_cryosis_closed_comments' );
endif;

if ( ! function_exists( 'dw_cryosis_setup' ) ) :
	function dw_cryosis_setup() {
		load_theme_textdomain( 'dw-cryosis', get_template_directory() . '/languages' );
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 190,
				'width'       => 190,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
		add_theme_support( 'title-tag' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support(
			'starter-content', 
			array(
				'widgets' => array(
					'left-sidebar'  => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'First Sidebar', 'dw-cryosis' ),
								'text'  => _x( 'This is some text in the first sidebar.', 'Theme Starter Content', 'dw-cryosis' ),
							),
						),
					),
					'center-block'  => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'Center Block', 'dw-cryosis' ),
								'text'  => _x( 'This is some text in the center block.', 'Theme Starter Content', 'dw-cryosis' ),
							),
						),
					),
					'right-sidebar' => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'Second Sidebar', 'dw-cryosis' ),
								'text'  => _x( 'This is some text in the second sidebar.', 'Theme Starter Content', 'dw-cryosis' ),
							),
						),
					),
				),
			)
		);
	}
	add_action( 'after_setup_theme', 'dw_cryosis_setup' );
endif;

if ( ! function_exists( 'dw_cryosis_register_menu' ) ) :
	function dw_cryosis_register_menu() {
		register_nav_menus(
			array(
				'header_nav_menu' => esc_html__( 'Header Nav Menu', 'dw-cryosis' ),
				'top_header_menu' => esc_html__( 'Top Header Menu', 'dw-cryosis' ),
			)
		);
	}
	add_action( 'init', 'dw_cryosis_register_menu' );
endif;

if ( ! function_exists( 'dw_cryosis_stylesheet' ) ) :
	function dw_cryosis_stylesheet() {
		wp_enqueue_style( 'dw-cryosis-style', get_stylesheet_directory_uri() . '/style.css', array(), wp_get_theme()->version );
		/* responsive design: */
		if ( is_active_sidebar( 'left-sidebar' ) && is_active_sidebar( 'right-sidebar' ) ) :
			wp_enqueue_style( 'dw-cryosis-mobile', get_stylesheet_directory_uri() . '/mobile.css', array(), wp_get_theme()->version, 'all and (max-width:899px)' );
			//if there are two sidebars, use mobile stylesheet at width<900
		elseif ( is_active_sidebar( 'left-sidebar' ) || is_active_sidebar( 'right-sidebar' ) ) :
			wp_enqueue_style( 'dw-cryosis-mobile', get_stylesheet_directory_uri() . '/mobile.css', array(), wp_get_theme()->version, 'all and (max-width:699px)' );
			//if there is one sidebar, use mobile stylesheet at width<700
		else :
			wp_enqueue_style( 'dw-cryosis-mobile', get_stylesheet_directory_uri() . '/mobile.css', array(), wp_get_theme()->version );
			//if there are no sidebars, use mobile stylesheet without width condition
		endif;
	}
	add_action( 'wp_enqueue_scripts', 'dw_cryosis_stylesheet' );
endif;

if ( ! function_exists( 'dw_cryosis_sidebars' ) ) :
	// register the sidebars
	function dw_cryosis_sidebars() {
		register_sidebar( 
			array(
				'name' => __( 'Header Bar', 'dw-cryosis' ),
				'id'   => 'top-block',
			)
		);
		register_sidebar( 
			array(
				'name' => __( 'Left Sidebar 1', 'dw-cryosis' ),
				'id'   => 'left-sidebar',
			)
		);
		register_sidebar( 
			array(
				'name' => __( 'Left Sidebar 2', 'dw-cryosis' ),
				'id'   => 'left-sidebar2',
			)
		);
		register_sidebar( 
			array(
				'name' => __( 'Left Sidebar 3', 'dw-cryosis' ),
				'id'   => 'left-sidebar3',
			)
		);
		register_sidebar( 
			array(
				'name' => __( 'Left Sidebar 4', 'dw-cryosis' ),
				'id'   => 'left-sidebar4',
			)
		);
		register_sidebar( 
			array(
				'name' => __( 'Left Sidebar 5', 'dw-cryosis' ),
				'id'   => 'left-sidebar5',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 1', 'dw-cryosis' ),
				'id'   => 'right-sidebar',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 2', 'dw-cryosis' ),
				'id'   => 'right-sidebar2',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 3', 'dw-cryosis' ),
				'id'   => 'right-sidebar3',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 4', 'dw-cryosis' ),
				'id'   => 'right-sidebar4',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 5', 'dw-cryosis' ),
				'id'   => 'right-sidebar5',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 1', 'dw-cryosis' ),
				'id'   => 'center-block',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 2', 'dw-cryosis' ),
				'id'   => 'center-block2',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 3', 'dw-cryosis' ),
				'id'   => 'center-block3',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 4', 'dw-cryosis' ),
				'id'   => 'center-block4',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 5', 'dw-cryosis' ),
				'id'   => 'center-block5',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Footer Bar', 'dw-cryosis' ),
				'id'   => 'bottom-block',
			)
		);
	}
	add_action( 'widgets_init', 'dw_cryosis_sidebars' );
endif;

// display information about a post under the post title
if ( ! function_exists( 'dw_cryosis_post_meta' ) ) :
	function dw_cryosis_post_meta() {
		echo '<div class="meta">';
		if ( get_post_type() === 'page' ) :
			printf(
				/* translators: %s = author */
				esc_html__( 'Posted by %s', 'dw-cryosis' ),
				get_the_author()
			);
		elseif ( has_category() ) :
			printf(
				/* translators: %1$s = date, %2$s = categories, %3$s = author */
				esc_html__( 'Posted on %1$s in %2$s by %3$s', 'dw-cryosis' ),
				get_the_date(),
				wp_kses_post( get_the_category_list( ',' ) ),
				get_the_author()
			);
		else :
			printf(
				/* translators: %1$s = date, %2$s = author */
				esc_html__( 'Posted on %1$s by %2$s', 'dw-cryosis' ),
				get_the_date(),
				get_the_author()
			);
		endif;
		edit_post_link( _x( 'Edit', 'verb', 'dw-cryosis' ), ' | ' );
		if ( get_post_type() !== 'page' && has_tag() ) :
			echo '<br>';
			the_tags();
		endif;
		echo '</div>';
	}
endif;

// change the archive title to show the search query when showing the archive title on a search result page.
if ( ! function_exists( 'dw_cryosis_search_title' ) ) :
	function dw_cryosis_search_title( $title ) {
		if ( is_search() ) {
			/* translators: %s = search query */
			$title = sprintf( __( 'Search: %s', 'dw-cryosis' ), get_search_query() );
		}
		return $title;
	}
	add_filter( 'get_the_archive_title', 'dw_cryosis_search_title' );
endif;

function dw_cryosis_google_fonts() {
	wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css2?family=Oswald:wght@200;300;400;500;600;700&display=swap', array(), wp_get_theme()->version );
}
add_action( 'wp_enqueue_scripts', 'dw_cryosis_google_fonts' );

// Enqueue Scripts
function dw_cryosis_enqueue_scripts() {
	wp_enqueue_script( 'dw-cryosis-top-button', get_template_directory_uri() . '/js/dw-cryosis-top-button.js', array(), wp_get_theme()->version, true );
}
add_action( 'wp_enqueue_scripts', 'dw_cryosis_enqueue_scripts' );

// Add Footer Text Box section to customize
function dw_cryosis_fcontent( $wp_customize ) {
	$wp_customize->add_section(
		'dw-cryosis-fcontent-section', 
		array(
			'title' => __( 'Footer Text Box', 'dw-cryosis' ),
		)
	);

	$wp_customize->add_setting(
		'dw-cryosis-fcontent-text', 
		array(
			'default'           => __( 'Example text for the footer box paragraph.', 'dw-cryosis' ),
			'sanitize_callback' => 'wp_kses_post',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-cryosis-fcontent-text-control', 
			array(
				'label'    => __( 'Footer Box Paragraph (HTML Accepted):', 'dw-cryosis' ),
				'section'  => 'dw-cryosis-fcontent-section',
				'settings' => 'dw-cryosis-fcontent-text',
				'type'     => 'textarea',
			)
		)
	);
}

add_action( 'customize_register', 'dw_cryosis_fcontent' );

// Premium Upgrade Section
function dw_cryosis_procontent( $wp_customize ) {
	$wp_customize->add_section(
		'pro_sec',
		array(
			'title'       => __( 'DESIGNWICKED', 'dw-cryosis' ),
			'description' => '',
			'priority'    => 1,
			'capability'  => 'edit_theme_options',
		) 
	);
	
	
	
	$wp_customize->add_control(
		'button_id',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => 
			array(
				'value'   => __( 'GET PREMIUM THEMES', 'dw-cryosis' ),
				'class'   => 'button-primary',
				'onclick' => "window.open('https:/www.designwicked.com/wordpress-themes', '_blank')",
			),
		) 
	);
	
	$wp_customize->add_control(
		'label', 
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Other Services - Click Below', 'dw-cryosis' ),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' =>
			array(
				'value'   => __( 'We also do custom themes, and more!', 'dw-cryosis' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https:/www.designwicked.com/services', '_blank')",
			),
		) 
	);
	
}
	
	add_action( 'customize_register', 'dw_cryosis_procontent' );
